# This file is part of FatxFast.
#
#    FatxFast is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    FatxFast is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with FatxFast.  If not, see <http://www.gnu.org/licenses/>.

# Versioning based on: 
# http://en.wikipedia.org/wiki/Versioning#Designating_development_stage
__author__ = "dryatu (c) 2013"
__version__ = "1.1.0"


from FatxFast.resource import resource_manager, get_color
import pygame
import os
from FatxFast.input import KeyListener, MouseListener

class Widget(KeyListener, MouseListener):
    
    def __init__(self, **kwargs):
        self.colorkey = get_color(kwargs.get("colorkey"))
        #self.auto_y_pos and self.auto_size are for determining if widget's size or y-pos
        #is defined in XML or if it is set automatically
        if kwargs.get("y") == "auto":
            self.auto_y_pos = True
            kwargs["y"] = 0
        else:
            self.auto_y_pos = False
                
        self.auto_size = None in [kwargs.get("width"), kwargs.get("height")]
        
        self.rect = pygame.Rect(kwargs.get("x", 0), kwargs.get("y", 0),
            kwargs.get("width", 0), kwargs.get("height", 0))
        
        if 'bgimage' in kwargs:
            self.image = resource_manager.load_image(
                kwargs['bgimage'], self.colorkey)
            self.rect.size = self.image.get_rect().size
        else:
            self.image = None
            
        self.bgcolor = get_color(kwargs.get("bgcolor"))
        self.container = kwargs.get("container")
        self.name = kwargs.get("name", "noname")
        self.connect_obj = kwargs.get("connect_obj")
        self.handler = kwargs.get("handler") 
        self.focus = None

    def get_focus(self):
        return self.focus
    
    def get_abs_rect(self):
        x, y = self.rect.x, self.rect.y
        current_container = self.container
        while current_container:
            x += current_container.rect.x
            y += current_container.rect.y
            current_container = current_container.container
        return pygame.Rect(x, y, self.rect.width, self.rect.height)
    
    def draw(self, surface):
        try:
            surf_rect = surface.get_rect()
            sub = surface.subsurface(self.rect.clip(surf_rect))
            if self.bgcolor:
                sub.fill(self.bgcolor)
            if self.image is not None: 
                if self.colorkey:
                    self.image.set_colorkey(self.colorkey)
                    sub.set_colorkey(self.colorkey)
                sub.blit(self.image, (0,0))
            return sub
        except ValueError:
            pass

    def kill(self):
        if self.container and self.name in self.container.widgets:
            return self.container.widgets.pop(self.name)

    def mouse_moved(self, pos, rel):
        self.set_focus(self.get_abs_rect().collidepoint(pos))
    
    def set_focus(self, value):
        self.focus = value

    def update(self, dt):
        pass

